@@ -1,9 +1,12 @@
 def q1(qn=0):
+    from importlib.resources import contents
     from PIL import ImageGrab
     from IPython.display import display, Image
     import os
     if not qn:
-        img = Image(filename='q1/q1_task1.png')
+        print(sorted(contents('pm20_5.q1')))
+        data = os.path.join(here, "q1", "q1_task1.png")
+        img = Image(filename=data)
         display(img)
         img = Image(filename='q1/q1_task2.png')
         display(img)
